================================
oslo.log -- Oslo Logging Library
================================

The oslo.log (logging) configuration library provides standardized
configuration for all openstack projects. It also provides custom
formatters, handlers and support for context specific
logging (like resource id's etc).

.. toctree::
   :maxdepth: 1

   install/index
   user/index
   reference/index
   configuration/index
   admin/index
   contributor/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
